ActionColours class final
Interactive element colour roles across all states and semantic intents.
Constructors
- ActionColours({required Color actionPrimary, required Color actionPrimaryHover, required Color actionPrimaryActive, required Color actionPrimaryDisabled, required Color actionSecondary, required Color actionSecondaryHover, required Color actionError, required Color actionErrorHover, required Color actionSuccess})
-
const
Properties
- actionError → Color
-
Destructive / error action surface.
final
- actionErrorHover → Color
-
Hover state of actionError.
final
- actionPrimary → Color
-
Primary CTA background (filled button, active toggle resting state).
final
- actionPrimaryActive → Color
-
Pressed / active state of actionPrimary.
final
- actionPrimaryDisabled → Color
-
Disabled primary action surface.
final
- actionPrimaryHover → Color
-
Hover state of actionPrimary.
final
- actionSecondary → Color
-
Secondary action background (outlined / ghost button resting surface).
final
- actionSecondaryHover → Color
-
Hover state of actionSecondary.
final
- actionSuccess → Color
-
Success / constructive action surface.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{Color? actionPrimary, Color? actionPrimaryHover, Color? actionPrimaryActive, Color? actionPrimaryDisabled, Color? actionSecondary, Color? actionSecondaryHover, Color? actionError, Color? actionErrorHover, Color? actionSuccess}) → ActionColours -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
ActionColours a, ActionColours b, double t) → ActionColours