tooltipLabel property
String
get
tooltipLabel
Semantic label announced by screen readers when a tooltip is shown.
Implementation
String get tooltipLabel;
Semantic label announced by screen readers when a tooltip is shown.
String get tooltipLabel;