DievasOpacityThemeData class final
The opacity sub-system for a Dievas theme.
Values are fractions in 0.0, 1.0, consumed by Opacity widgets,
Color.withOpacity, and animation curves.
Constructors
- DievasOpacityThemeData({double disabled = DievasOpacitySemantic.disabled, double hoverGhost = DievasOpacitySemantic.hoverGhost, double pressedGhost = DievasOpacitySemantic.pressedGhost, double focusRing = DievasOpacitySemantic.focusRing, double overlay = DievasOpacitySemantic.overlay, double transparent = DievasOpacitySemantic.transparent, double opaque = DievasOpacitySemantic.opaque})
-
const
Properties
- disabled → double
-
40% — disabled interactive elements (buttons, inputs, icons).
final
- focusRing → double
-
10% — focus ring fill.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverGhost → double
-
8% — ghost hover surface tint (icon buttons, list tiles).
final
- opaque → double
-
100% — fully opaque. Animation end states and solid surfaces.
final
- overlay → double
-
56% — modal / bottom sheet scrim overlay.
final
- pressedGhost → double
-
16% — pressed / active surface tint.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - transparent → double
-
0% — fully transparent. Animation start states.
final
Methods
-
copyWith(
{double? disabled, double? hoverGhost, double? pressedGhost, double? focusRing, double? overlay, double? transparent, double? opaque}) → DievasOpacityThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited