DievasThemeAspect enum
Named aspects of the Dievas theme — used by DievasTheme (InheritedModel) to scope rebuilds to only the widgets that depend on a changed aspect.
Example: a widget that reads only DievasThemeAspect.colors will not rebuild when DievasThemeAspect.spacing changes.
Values
- animation → const DievasThemeAspect
- border → const DievasThemeAspect
- colors → const DievasThemeAspect
- components → const DievasThemeAspect
- elevation → const DievasThemeAspect
- material → const DievasThemeAspect
- opacity → const DievasThemeAspect
- sizing → const DievasThemeAspect
- spacing → const DievasThemeAspect
- typography → const DievasThemeAspect
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DievasThemeAspect> - A constant List of the values in this enum, in order of their declaration.