FeedbackColour class final
A value object holding the four colour sub-roles for a single feedback semantic (success, warning, error, or info).
Constructors
- FeedbackColour({required Color background, required Color border, required Color icon, required Color text})
-
const
Properties
- background → Color
-
Alert / toast surface background.
final
- border → Color
-
Container border stroke.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Color
-
Icon fill within the alert.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - text → Color
-
Body text within the alert.
final
Methods
-
copyWith(
{Color? background, Color? border, Color? icon, Color? text}) → FeedbackColour -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
FeedbackColour a, FeedbackColour b, double t) → FeedbackColour